from .main import *

__copyright__    = 'Copyright (C) 2022 tsubasa652'
__version__      = '1.0.0'
__license__      = 'MIT'
__author__       = 'tsubasa652'
__author_email__ = 'mail@tsubasa.ml'
__url__          = 'http://github.com/tsubasa652/python-shortlink-extractor'

__all__ = [extract_short_link]


from urllib.parse import urlparse
from http import client

def extract_short_link(url):
    host = urlparse(url).netloc
    path = urlparse(url).path
    c = client.HTTPSConnection(host)
    c.request("GET", path)

    r = c.getresponse()
    c.close()
    if(r.status == 301 or r.status == 302):
        return extract_short_link(r.headers["Location"])
    else:
        return url
